@@ -7,7 +7,7 @@ This example shows how to plot a scatter chart.
 """
 
 import numpy as np
-from matplotlib import cm
+from matplotlib import colormaps
 import matplotlib.pyplot as plt
 from matplotlib.colors import ListedColormap
 
@@ -92,7 +92,7 @@ txt = ax.text(x=40, y=80, s='Barcelona shots\nversus Sevilla',
 # You could use the same technique to assign fewer colors to the scatter.
 
 # get the cmap as 10 colors (n_colors can be anything)
-cmap = cm.get_cmap('Greys')  # reversed plasma
+cmap = colormaps.get_cmap('Greys')  # reversed plasma
 N_COLORS = 10
 cmap = cmap(np.linspace(0.5, 1, N_COLORS))  # from half-way (0.5) to end (1) of grey colormap
 cmap = ListedColormap(cmap, name='Greys')
@@ -146,7 +146,7 @@ txt = ax.text(x=40, y=80, s='Barcelona shots\nversus Sevilla',
 # Another method popularized by `@petermckeever <https://twitter.com/petermckeever>`_.
 # is to use hatch patterns to show where something was not-successful versus successful.
 # There are lots of different hatch patterns.
-# See: matplotlib.org/api/_as_gen/matplotlib.patches.Patch.html#matplotlib.patches.Patch.set_hatch
+# See set_hatch: https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html
 # This is typically combined with the highlight-text package
 # by `@danzn1 <https://twitter.com/danzn1>`_.
 
@@ -212,7 +212,7 @@ sc2 = pitch.scatter(df_goals_barca.x, df_goals_barca.y,
                     # size varies between 100 and 1900 (points squared)
                     s=(df_goals_barca.shot_statsbomb_xg * 1900) + 100,
                     edgecolors='#b94b75',
-                    linewidth=0.6,
+                    linewidths=0.6,
                     c='white',
                     marker='football',
                     ax=ax)
@@ -329,14 +329,14 @@ title2 = axs['title'].text(0.5, 0.25, "versus Sevilla", color=pitch.line_color,
 # In a horizontal pitch, 0 degrees is this way →, in a vertical pitch, 0 degrees is this way ↑
 #
 # We are going to plot pass data as an arrowhead marker with the
-# arrow facing in the direction of the pass
+# arrow facing in the direction of the pass.
 # The marker size is going to relate to the pass distance,
 # so larger markers mean the pass was longer.
 pitch = Pitch()
 fig, ax = pitch.draw(figsize=(14, 12))
 angle, distance = pitch.calculate_angle_and_distance(df_pass_barca.x, df_pass_barca.y,
                                                      df_pass_barca.end_x, df_pass_barca.end_y,
-                                                     standardized=False, degrees=True)
+                                                     degrees=True)
 sc = pitch.scatter(df_pass_barca.x, df_pass_barca.y, rotation_degrees=angle,
                    c='#b94b75',  # color for scatter in hex format
                    edgecolors='#383838', alpha=0.9,
