@@ -1,25 +1,20 @@
 """ Module adds the plotting methods to the BasePitch abstract class."""
 
-from collections import namedtuple
-
-import matplotlib.docstring as docstring
-import matplotlib.patches as patches
 import numpy as np
 import seaborn as sns
+from matplotlib import patches
 from matplotlib import rcParams
-from matplotlib.collections import PatchCollection
 from scipy.spatial import Voronoi, ConvexHull
 from scipy.stats import circmean
 
 from mplsoccer._pitch_base import BasePitch
-from mplsoccer.heatmap import bin_statistic, bin_statistic_positional, heatmap, heatmap_positional
+from mplsoccer.heatmap import (bin_statistic, bin_statistic_positional,
+                               bin_statistic_sonar, sonar, heatmap,
+                               heatmap_positional)
 from mplsoccer.linecollection import lines
 from mplsoccer.quiver import arrows
 from mplsoccer.scatterutils import scatter_football, scatter_rotation
-from mplsoccer.utils import validate_ax
-
-_BinnedStatisticResult = namedtuple('BinnedStatisticResult',
-                                    ('statistic', 'x_grid', 'y_grid', 'cx', 'cy'))
+from mplsoccer.utils import validate_ax, copy_doc
 
 
 class BasePitchPlot(BasePitch):
@@ -100,7 +95,6 @@ class BasePitchPlot(BasePitch):
         >>> pitch.scatter(30, 30, marker='football', ax=ax)
         """
         validate_ax(ax)
-
         x = np.ma.ravel(x)
         y = np.ma.ravel(y)
 
@@ -116,13 +110,11 @@ class BasePitchPlot(BasePitch):
             raise NotImplementedError("rotated football markers are not implemented.")
 
         if marker == 'football':
-            scatter_plot = scatter_football(x, y, ax=ax, **kwargs)
-        elif rotation_degrees is not None:
-            scatter_plot = scatter_rotation(x, y, rotation_degrees, marker=marker,
-                                            vertical=self.vertical, ax=ax, **kwargs)
-        else:
-            scatter_plot = ax.scatter(x, y, marker=marker, **kwargs)
-        return scatter_plot
+            return scatter_football(x, y, ax=ax, **kwargs)
+        if rotation_degrees is not None:
+            return scatter_rotation(x, y, rotation_degrees, marker=marker,
+                                    vertical=self.vertical, ax=ax, **kwargs)
+        return ax.scatter(x, y, marker=marker, **kwargs)
 
     def _reflect_2d(self, x, y, standardized=False):
         """ Reflect data in the pitch lines."""
@@ -161,7 +153,7 @@ class BasePitchPlot(BasePitch):
         >>> fig, ax = pitch.draw()
         >>> x = np.random.uniform(low=0, high=120, size=100)
         >>> y = np.random.uniform(low=0, high=80, size=100)
-        >>> pitch.kdeplot(x, y, cmap='Reds', shade=True, levels=100, ax=ax)
+        >>> pitch.kdeplot(x, y, cmap='Reds', fill=True, levels=100, ax=ax)
         """
         validate_ax(ax)
 
@@ -172,8 +164,7 @@ class BasePitchPlot(BasePitch):
 
         x, y = self._reverse_if_vertical(x, y)
 
-        contour_plot = sns.kdeplot(x=x, y=y, ax=ax, clip=self.kde_clip, **kwargs)
-        return contour_plot
+        return sns.kdeplot(x=x, y=y, ax=ax, clip=self.kde_clip, **kwargs)
 
     def hexbin(self, x, y, ax=None, **kwargs):
         """ Utility wrapper around matplotlib.axes.Axes.hexbin,
@@ -271,7 +262,7 @@ class BasePitchPlot(BasePitch):
         return patch_list
 
     def goal_angle(self, x, y, ax=None, goal='right', **kwargs):
-        """ Plot a polygon with the angle to the goal using PatchCollection.
+        """ Plot a polygon with the angle to the goal using matplotlib.patches.Polygon.
         See: https://matplotlib.org/stable/api/collections_api.html.
         Valid Collection keyword arguments: edgecolors, facecolors, linewidths, antialiaseds,
         transOffset, norm, cmap
@@ -289,7 +280,7 @@ class BasePitchPlot(BasePitch):
 
         Returns
         -------
-        PatchCollection : matplotlib.collections.PatchCollection
+        Polygon : matplotlib.patches.Polygon
 
         Examples
         --------
@@ -306,16 +297,12 @@ class BasePitchPlot(BasePitch):
         y = np.ravel(y)
         if x.size != y.size:
             raise ValueError("x and y must be the same size")
-        if goal == 'right':
-            goal_coordinates = self.goal_right
-        else:
-            goal_coordinates = self.goal_left
+        goal_coordinates = self.goal_right if goal == 'right' else self.goal_left
         verts = np.zeros((x.size, 3, 2))
         verts[:, 0, 0] = x
         verts[:, 0, 1] = y
         verts[:, 1:, :] = np.expand_dims(goal_coordinates, 0)
-        patch_collection = self.polygon(verts, ax=ax, **kwargs)
-        return patch_collection
+        return self.polygon(verts, ax=ax, **kwargs)
 
     def annotate(self, text, xy, xytext=None, ax=None, **kwargs):
         """ Utility wrapper around ax.annotate
@@ -345,8 +332,8 @@ class BasePitchPlot(BasePitch):
         >>> from mplsoccer import Pitch
         >>> pitch = Pitch()
         >>> fig, ax = pitch.draw()
-        >>> pitch.annotate(text='center', xytext=(50, 50), xy=(60, 40), ha='center', va='center', \
-                           ax=ax, arrowprops=dict(facecolor='black'))
+        >>> pitch.annotate(text='center', xytext=(50, 50), xy=(60, 40), ha='center', va='center',
+        ...                ax=ax, arrowprops=dict(facecolor='black'))
         """
         validate_ax(ax)
         xy = self._reverse_annotate_if_vertical(xy)
@@ -354,32 +341,178 @@ class BasePitchPlot(BasePitch):
             xytext = self._reverse_annotate_if_vertical(xytext)
         return ax.annotate(text, xy, xytext, **kwargs)
 
-    @docstring.copy(bin_statistic)
+    def text(self, x, y, s, ax=None, **kwargs):
+        """ Utility wrapper around ax.text
+        which automatically flips the x/y coordinates if the pitch is vertical.
+
+        See: https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html
+
+        Parameters
+        ----------
+        x, y : float
+            The position to place the text
+        s : str
+            The text
+        ax : matplotlib.axes.Axes, default None
+            The axis to plot on.
+        **kwargs : All other keyword arguments are passed on to matplotlib.axes.Axes.text.
+
+        Returns
+        -------
+        text : matplotlib.text.Text
+
+        Examples
+        --------
+        >>> from mplsoccer import Pitch
+        >>> pitch = Pitch()
+        >>> fig, ax = pitch.draw()
+        >>> pitch.text(60, 40, 'Center of the pitch', va='center', ha='center', ax=ax)
+        """
+        validate_ax(ax)
+        x, y = self._reverse_if_vertical(x, y)
+        return ax.text(x, y, s, **kwargs)
+
+    @copy_doc(bin_statistic)
     def bin_statistic(self, x, y, values=None, statistic='count', bins=(5, 4),
                       normalize=False, standardized=False):
-        stats = bin_statistic(x, y, values=values, dim=self.dim, statistic=statistic,
-                              bins=bins, normalize=normalize, standardized=standardized)
-        return stats
+        return bin_statistic(x, y, values=values, dim=self.dim, statistic=statistic,
+                             bins=bins, normalize=normalize, standardized=standardized)
 
-    @docstring.copy(heatmap)
+    @copy_doc(bin_statistic_sonar)
+    def bin_statistic_sonar(self, x, y, angle, values=None,
+                            statistic='count', bins=(5, 4, 10),
+                            normalize=False, standardized=False, center=True):
+        return bin_statistic_sonar(x, y, angle, values=values, dim=self.dim,
+                                   statistic=statistic, bins=bins,
+                                   normalize=normalize, standardized=standardized,
+                                   center=center)
+
+    @staticmethod
+    @copy_doc(sonar)
+    def sonar(stats_length, xindex=0, yindex=0,
+              stats_color=None, cmap=None, vmin=None, vmax=None,
+              rmin=0, rmax=None,
+              sonar_alpha=1, sonar_facecolor='None',
+              axis=False, label=False,
+              ax=None,
+              **kwargs):
+        return sonar(stats_length, xindex=xindex, yindex=yindex,
+                     stats_color=stats_color, cmap=cmap, vmin=vmin, vmax=vmax,
+                     rmin=rmin, rmax=rmax,
+                     sonar_alpha=sonar_alpha, sonar_facecolor=sonar_facecolor,
+                     axis=axis, label=label, ax=ax, **kwargs)
+
+    def sonar_grid(self, stats_length,
+                   stats_color=None, cmap=None, vmin=None, vmax=None,
+                   rmin=0, rmax=None,
+                   sonar_alpha=1, sonar_facecolor='None',
+                   axis=False, label=False,
+                   width=None, height=None,
+                   exclude_zeros=True, exclude_nan=True,
+                   ax=None, **kwargs):
+        """ Plot a grid of polar bar charts on an existing axes.
+
+        Parameters
+        ----------
+        stats_length : dict
+            This should be calculated via bin_statistic_sonar().
+            It controls the length of the bars.
+        stats_color : dict, default None
+            This should be calculated via bin_statistic_sonar().
+            It controls the color of the bars via a cmap. The vmin/vmax
+            arguments will set the boundaries for the cmap.
+            If stats_color is None then the color of the bars is controlled
+            by 'color', 'fc', or 'facecolor' arguments.
+        cmap : str or matplotlib.colros.Colormap, default None
+            Controls the color of the bars via stats_color.
+        vmin, vmax : float, default None
+            The cmap is mapped linearly to the range vmin to vmax, so that values
+            equal to or less than vmin are given the first color in the cmap
+            and values equal to or greater than vmax are given the last color
+            in the cmap. The default of None sets the values to the minimum value of
+            stats_color['statistic'] and the maximum value of stats_color['statistic'].
+        rmin, rmax : float, default 0 and None
+            The radial axis limits. The default rmax of None sets the values to the maximum
+            of stats_length['statistic'].
+        sonar_alpha : float, default 1
+            The alpha/ transparency of the sonar axes patch.
+        sonar_facecolor : any Matplotlib color, default 'None'
+            The facecolor of the sonar axes. The default 'None' makes the axes transparent.
+        axis : bool, default False
+            Whether to set the axis spines to visible.
+        label : bool, default False
+            Whether to include the axis labels.
+        width, height : float, default None
+            The width, height of the inset Polar axes in the x/y data coordinates.
+            You should only provide one of the width or height arguments
+            since the Polar axes are square and the other values is set dynamically.
+        exclude_zeros : bool, default True
+            Whether to draw the Polar axes where all the values are zero for the grid cell.
+        exclude_nan : bool, default True
+            Whether to draw the Polar axes where all the values are numpy.nan for the grid cell.
+        ax : matplotlib.axes.Axes, default None
+            The axis to plot on.
+        **kwargs : All other keyword arguments are passed on to matplotlib.axes.Axes.bar.
+
+        Examples
+        --------
+        >>> from mplsoccer import Pitch, Sbopen
+        >>> parser = Sbopen()
+        >>> df = parser.event(69251)[0]
+        >>> df = df[(df.type_name == 'Pass') &
+        ...         (df.outcome_name.isnull())].copy()
+        >>> pitch = Pitch()
+        >>> angle, distance = pitch.calculate_angle_and_distance(df.x, df.y,
+        ...                                                      df.end_x, df.end_y)
+        >>> bs = pitch.bin_statistic_sonar(df.x, df.y, angle,
+        ...                                bins=(6, 4, 4), center=True)
+        >>> fig, ax = pitch.draw(figsize=(8, 5.5))
+        >>> axs = pitch.sonar_grid(bs, width=10, fc='cornflowerblue',
+        ...                        ec='black', ax=ax)
+        """
+        validate_ax(ax)
+        mask_zero = np.all(np.isclose(stats_length['statistic'], 0), axis=2)
+        mask_null = np.all(np.isnan(stats_length['statistic']), axis=2)
+        axs = np.empty(stats_length['cx'].shape, dtype='O')
+        it = np.nditer(stats_length['cx'], flags=['multi_index'])
+        for cx in it:
+            if mask_zero[it.multi_index] and exclude_zeros:
+                ax_inset = None
+            elif mask_null[it.multi_index] and exclude_nan:
+                ax_inset = None
+            else:
+                ax_inset = self.inset_axes(cx, stats_length['cy'][it.multi_index],
+                                        width=width, height=height, ax=ax, polar=True)
+                sonar(stats_length=stats_length,
+                    xindex=it.multi_index[1], yindex=it.multi_index[0],
+                    stats_color=stats_color, cmap=cmap, vmin=vmin, vmax=vmax,
+                    rmin=rmin, rmax=rmax,
+                    sonar_alpha=sonar_alpha, sonar_facecolor=sonar_facecolor,
+                    axis=axis, label=label,
+                    ax=ax_inset, **kwargs)
+            axs[it.multi_index] = ax_inset
+        axs = np.squeeze(axs)
+        if axs.size == 1:
+            axs = axs.item()
+        return axs
+
+    @copy_doc(heatmap)
     def heatmap(self, stats, ax=None, **kwargs):
-        mesh = heatmap(stats, ax=ax, vertical=self.vertical, **kwargs)
-        return mesh
+        return heatmap(stats, ax=ax, vertical=self.vertical, **kwargs)
 
-    @docstring.copy(bin_statistic_positional)
+    @copy_doc(bin_statistic_positional)
     def bin_statistic_positional(self, x, y, values=None, positional='full',
                                  statistic='count', normalize=False):
-        stats = bin_statistic_positional(x, y, values=values,
-                                         dim=self.dim, positional=positional,
-                                         statistic=statistic, normalize=normalize)
-        return stats
+        return bin_statistic_positional(x, y, values=values,
+                                        dim=self.dim, positional=positional,
+                                        statistic=statistic, normalize=normalize)
 
-    @docstring.copy(heatmap_positional)
+    @copy_doc(heatmap_positional)
     def heatmap_positional(self, stats, ax=None, **kwargs):
-        mesh = heatmap_positional(stats, ax=ax, vertical=self.vertical, **kwargs)
-        return mesh
+        return heatmap_positional(stats, ax=ax, vertical=self.vertical, **kwargs)
 
-    def label_heatmap(self, stats, str_format=None, exclude_zeros=False, ax=None, **kwargs):
+    def label_heatmap(self, stats, str_format=None, exclude_zeros=False, exclude_nan=False,
+                      xoffset=0, yoffset=0, ax=None, **kwargs):
         """ Labels the heatmap(s) and automatically flips the coordinates if the pitch is vertical.
 
         Parameters
@@ -388,16 +521,20 @@ class BasePitchPlot(BasePitch):
             This should be calculated via bin_statistic_positional() or bin_statistic().
         str_format : str
             A format string passed to str_format.format() to format the labels.
-        exclude_zeros : bool
+        exclude_zeros : bool, default False
             Whether to exclude zeros when labelling the heatmap.
+        exclude_nan : bool, default False
+            Whether to exclude numpy.nan when labelling the heatmap.
+        xoffset, yoffset : float, default 0
+            The amount in data coordinates to offset the labels from the center of the grid cell.
         ax : matplotlib.axes.Axes, default None
             The axis to plot on.
 
-        **kwargs : All other keyword arguments are passed on to matplotlib.axes.Axes.annotate.
+        **kwargs : All other keyword arguments are passed on to matplotlib.text.Text.
 
         Returns
         -------
-        annotations : A list of matplotlib.text.Annotation.
+        text : A list of matplotlib.text.Text.
 
         Examples
         --------
@@ -410,12 +547,13 @@ class BasePitchPlot(BasePitch):
         >>> y = np.random.uniform(low=0, high=80, size=100)
         >>> stats = pitch.bin_statistic(x, y)
         >>> pitch.heatmap(stats, edgecolors='black', cmap='hot', ax=ax)
-        >>> stats['statistic'] = stats['statistic'].astype(int)
         >>> path_eff = [path_effects.Stroke(linewidth=0.5, foreground='#22312b')]
-        >>> text = pitch.label_heatmap(stats, color='white', ax=ax, fontsize=20, ha='center', \
-                                       va='center', path_effects=path_eff)
+        >>> text = pitch.label_heatmap(stats, color='white', ax=ax, fontsize=20, ha='center',
+        ...                            va='center', path_effects=path_eff, str_format='{:.0f}')
         """
         validate_ax(ax)
+        va = kwargs.pop('va', 'center')
+        ha = kwargs.pop('ha', 'center')
 
         if not isinstance(stats, list):
             stats = [stats]
@@ -430,35 +568,36 @@ class BasePitchPlot(BasePitch):
             mask_clip = mask_x_outside1 | mask_x_outside2 | mask_y_outside1 | mask_y_outside2
             if exclude_zeros:
                 mask_clip = mask_clip | (np.isclose(bin_stat['statistic'], 0.))
+            if exclude_nan:
+                mask_clip = mask_clip | np.isnan(bin_stat['statistic'])
             mask_clip = np.ravel(mask_clip)
 
             text = np.ravel(bin_stat['statistic'])[~mask_clip]
-            cx = np.ravel(bin_stat['cx'])[~mask_clip]
-            cy = np.ravel(bin_stat['cy'])[~mask_clip]
+            cx = np.ravel(bin_stat['cx'])[~mask_clip] + xoffset
+            cy = np.ravel(bin_stat['cy'])[~mask_clip] + yoffset
             for idx, text_str in enumerate(text):
                 if str_format is not None:
                     text_str = str_format.format(text_str)
-                annotation = self.annotate(text_str, (cx[idx], cy[idx]), ax=ax, **kwargs)
+                annotation = self.text(cx[idx], cy[idx], text_str, ax=ax,
+                                       va=va, ha=ha, **kwargs)
                 annotation_list.append(annotation)
 
         return annotation_list
 
-    @docstring.copy(arrows)
+    @copy_doc(arrows)
     def arrows(self, xstart, ystart, xend, yend, *args, ax=None, **kwargs):
         validate_ax(ax)
-        quiver = arrows(xstart, ystart, xend, yend, *args, ax=ax, vertical=self.vertical, **kwargs)
-        return quiver
+        return arrows(xstart, ystart, xend, yend, *args, ax=ax, vertical=self.vertical, **kwargs)
 
-    @docstring.copy(lines)
+    @copy_doc(lines)
     def lines(self, xstart, ystart, xend, yend, color=None, n_segments=100,
               comet=False, transparent=False, alpha_start=0.01,
               alpha_end=1, cmap=None, ax=None, **kwargs):
         validate_ax(ax)
-        linecollection = lines(xstart, ystart, xend, yend, color=color, n_segments=n_segments,
-                               comet=comet, transparent=transparent, alpha_start=alpha_start,
-                               alpha_end=alpha_end, cmap=cmap, ax=ax, vertical=self.vertical,
-                               reverse_cmap=self.reverse_cmap, **kwargs)
-        return linecollection
+        return lines(xstart, ystart, xend, yend, color=color, n_segments=n_segments,
+                     comet=comet, transparent=transparent, alpha_start=alpha_start,
+                     alpha_end=alpha_end, cmap=cmap, ax=ax, vertical=self.vertical,
+                     reverse_cmap=self.reverse_cmap, **kwargs)
 
     def convexhull(self, x, y):
         """ Get lines of Convex Hull for a set of coordinates
@@ -485,8 +624,7 @@ class BasePitchPlot(BasePitch):
         """
         points = np.vstack([x, y]).T
         hull = ConvexHull(points)
-        hull_vertices = points[hull.vertices].reshape(1, -1, 2)
-        return hull_vertices
+        return points[hull.vertices].reshape(1, -1, 2)
 
     def voronoi(self, x, y, teams):
         """ Get Voronoi vertices for a set of coordinates.
@@ -495,7 +633,7 @@ class BasePitchPlot(BasePitch):
         the edges of the pitch. See:
         https://github.com/ProformAnalytics/tutorial_nbs/blob/master/notebooks/Voronoi%20Reflection%20Trick.ipynb
 
-        Players outside of the pitch dimensions are assumed to be standing on the pitch edge.
+        Players outside the pitch dimensions are assumed to be standing on the pitch edge.
         This means that their coordinates are clipped to the pitch edges
         before calculating the Voronoi.
 
@@ -541,7 +679,7 @@ class BasePitchPlot(BasePitch):
         if teams.size != x.size:
             raise ValueError("x and team must be the same size")
 
-        if self.dim.aspect != 1:
+        if not self.dim.aspect_equal:
             standardized = True
             x, y = self.standardizer.transform(x, y)
             extent = np.array([0, 105, 0, 68])
@@ -568,7 +706,7 @@ class BasePitchPlot(BasePitch):
             verts = vor.vertices[region]
             verts[:, 0] = np.clip(verts[:, 0], a_min=extent[0], a_max=extent[1])
             verts[:, 1] = np.clip(verts[:, 1], a_min=extent[2], a_max=extent[3])
-            # convert back to coordinates if previously standardized
+            # convert coordinates back if previously standardized
             if standardized:
                 x_std, y_std = self.standardizer.transform(verts[:, 0], verts[:, 1], reverse=True)
                 verts[:, 0] = x_std
@@ -582,8 +720,7 @@ class BasePitchPlot(BasePitch):
 
         return team1, team2
 
-    def calculate_angle_and_distance(self, xstart, ystart, xend, yend,
-                                     standardized=False, degrees=False):
+    def calculate_angle_and_distance(self, xstart, ystart, xend, yend, degrees=False):
         """ Calculates the angle in radians counter-clockwise and the distance
         between a start and end location. Where the angle 0 is this way →
         (the straight line from left to right) in a horizontally orientated pitch
@@ -595,9 +732,6 @@ class BasePitchPlot(BasePitch):
         xstart, ystart, xend, yend: array-like or scalar.
             Commonly, these parameters are 1D arrays.
             These should be the start and end coordinates to calculate the angle between.
-        standardized : bool, default False
-            Whether the x, y values have been standardized to the 'uefa'
-            pitch coordinates (105m x 68m)
         degrees : bool, default False
             If False, the angle is returned in radians counter-clockwise in the range [0, 2pi]
             If True, the angle is returned in degrees clockwise in the range [0, 360].
@@ -623,7 +757,6 @@ class BasePitchPlot(BasePitch):
         ystart = np.ravel(ystart)
         xend = np.ravel(xend)
         yend = np.ravel(yend)
-
         if xstart.size != ystart.size:
             raise ValueError("xstart and ystart must be the same size")
         if xstart.size != xend.size:
@@ -631,6 +764,13 @@ class BasePitchPlot(BasePitch):
         if ystart.size != yend.size:
             raise ValueError("ystart and yend must be the same size")
 
+        if not self.dim.aspect_equal:
+            xstart, ystart = self.standardizer.transform(xstart, ystart)
+            xend, yend = self.standardizer.transform(xend, yend)
+            standardized = True
+        else:
+            standardized = False
+
         x_dist = xend - xstart
         if self.dim.invert_y and standardized is False:
             y_dist = ystart - yend
@@ -696,10 +836,9 @@ class BasePitchPlot(BasePitch):
 
         Examples
         --------
-        >>> from mplsoccer import Pitch
-        >>> from mplsoccer.statsbomb import read_event, EVENT_SLUG
-        >>> df = read_event(f'{EVENT_SLUG}/7478.json', related_event_df=False, \
-                            shot_freeze_frame_df=False, tactics_lineup_df=False)['event']
+        >>> from mplsoccer import Pitch, Sbopen
+        >>> parser = Sbopen()
+        >>> df, related, freeze, tactics = parser.event(7478)
         >>> team1, team2 = df.team_name.unique()
         >>> mask_team1 = (df.type_name == 'Pass') & (df.team_name == team1)
         >>> df = df[mask_team1].copy()
@@ -707,29 +846,34 @@ class BasePitchPlot(BasePitch):
         >>> fig, ax = pitch.draw()
         >>> bs_heatmap = pitch.bin_statistic(df.x, df.y, statistic='count', bins=(6, 4))
         >>> hm = pitch.heatmap(bs_heatmap, ax=ax, cmap='Blues')
-        >>> fm = pitch.flow(df.x, df.y, df.end_x, df.end_y, color='black', arrow_type='same', \
-                            arrow_length=6, bins=(6, 4), headwidth=2, headlength=2, \
-                            headaxislength=2, ax=ax)
+        >>> fm = pitch.flow(df.x, df.y, df.end_x, df.end_y, color='black', arrow_type='same',
+        ...                 arrow_length=6, bins=(6, 4), headwidth=2, headlength=2,
+        ...                 headaxislength=2, ax=ax)
         """
         validate_ax(ax)
-        if self.dim.aspect != 1:
+        # calculate  the binned statistics
+        angle, distance = self.calculate_angle_and_distance(xstart, ystart, xend, yend)
+
+        if not self.dim.aspect_equal:
             standardized = True
+            # slightly inefficient as we also transform the data
+            # in the calculate_angle_and_distance method
+            # but I wanted to make it easier for users as this way they do not need
+            # to know whether their data needs
+            # to be transformed for calculate_angle_and_distance
             xstart, ystart = self.standardizer.transform(xstart, ystart)
             xend, yend = self.standardizer.transform(xend, yend)
         else:
             standardized = False
 
-        # calculate  the binned statistics
-        angle, distance = self.calculate_angle_and_distance(xstart, ystart, xend, yend,
-                                                            standardized=standardized)
         bs_distance = self.bin_statistic(xstart, ystart, values=distance,
                                          statistic='mean', bins=bins, standardized=standardized)
         bs_angle = self.bin_statistic(xstart, ystart, values=angle,
                                       statistic=circmean, bins=bins, standardized=standardized)
 
         # calculate the arrow length
-        if self.pitch_type == 'tracab':
-            arrow_length = arrow_length * 100
+        if self.dim.pad_multiplier != 1:
+            arrow_length = arrow_length * self.dim.pad_multiplier
         if arrow_type == 'scale':
             new_d = (bs_distance['statistic'] * arrow_length /
                      np.nan_to_num(bs_distance['statistic']).max(initial=None))
@@ -743,7 +887,7 @@ class BasePitchPlot(BasePitch):
 
         # calculate the end positions of the arrows
         endx = bs_angle['cx'] + (np.cos(bs_angle['statistic']) * new_d)
-        if self.dim.invert_y and standardized is False:
+        if self.dim.invert_y and not standardized:
             endy = bs_angle['cy'] - (np.sin(bs_angle['statistic']) * new_d)  # invert_y
         else:
             endy = bs_angle['cy'] + (np.sin(bs_angle['statistic']) * new_d)
@@ -755,14 +899,11 @@ class BasePitchPlot(BasePitch):
             endx, endy = self.standardizer.transform(endx, endy, reverse=True)
 
         # plot arrows
-        if color is None:
-            bs_count = self.bin_statistic(xstart, ystart, statistic='count',
-                                          bins=bins, standardized=standardized)
-            flow = self.arrows(cx, cy, endx, endy, bs_count['statistic'], ax=ax, **kwargs)
-        else:
-            flow = self.arrows(cx, cy, endx, endy, color=color, ax=ax, **kwargs)
-
-        return flow
+        if color is not None:
+            return self.arrows(cx, cy, endx, endy, color=color, ax=ax, **kwargs)
+        bs_count = self.bin_statistic(xstart, ystart, statistic='count',
+                                      bins=bins, standardized=standardized)
+        return self.arrows(cx, cy, endx, endy, bs_count['statistic'], ax=ax, **kwargs)
 
     def triplot(self, x, y, ax=None, **kwargs):
         """ Utility wrapper around matplotlib.axes.Axes.triplot
@@ -779,18 +920,27 @@ class BasePitchPlot(BasePitch):
         x, y = self._reverse_if_vertical(x, y)
         return ax.triplot(x, y, **kwargs)
 
-    # The methods below for drawing/ setting attributes for some of the pitch elements
+    # The methods below for drawing/ setting attributes for some pitch elements
     # are defined in pitch.py (Pitch/ VerticalPitch classes)
     # as they differ for horizontal/ vertical pitches
     def _scale_pad(self):
         pass
 
+    def _set_aspect(self):
+        pass
+
     def _set_extent(self):
         pass
 
+    def _validate_pad(self):
+        pass
+
     def _draw_rectangle(self, ax, x, y, width, height, **kwargs):
         pass
 
+    def _draw_centered_rectangle(self, ax, x, y, width, height, **kwargs):
+        pass
+
     def _draw_line(self, ax, x, y, **kwargs):
         pass
 
