@@ -5,8 +5,8 @@ Author: Anmol_Durgapal(@slothfulwave612)
 The idea is inspired by Tom Worville, Football Slices, Soma Zero FC and Soumyajit Bose.
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 __all__ = ["PyPizza"]
 
@@ -59,14 +59,24 @@ class PyPizza:
         self.straight_line_limit = straight_line_limit
         self.straight_line_color = straight_line_color
         self.straight_line_lw = straight_line_lw
-        self.straight_line_ls = straight_line_ls
+        # if any of the linewidths are zero set the linestyle to solid
+        # to prevent https://github.com/andrewRowlinson/mplsoccer/issues/71
+        if straight_line_lw == 0:
+            self.straight_line_ls = 'solid'
+        else:
+            self.straight_line_ls = straight_line_ls
         self.last_circle_color = last_circle_color
         self.last_circle_lw = last_circle_lw
-        self.last_circle_ls = last_circle_ls
+        if last_circle_lw == 0:
+            self.last_circle_ls = 'solid'
+        else:
+            self.last_circle_ls = last_circle_ls
         self.other_circle_color = other_circle_color
         self.other_circle_lw = other_circle_lw
-        self.other_circle_ls = other_circle_ls
-
+        if other_circle_lw == 0:
+            self.other_circle_ls = 'solid'
+        else:
+            self.other_circle_ls = other_circle_ls
         self.param_texts = []
         self.value_texts = []
         self.compare_value_texts = []
@@ -90,8 +100,10 @@ class PyPizza:
                 f'other_circle_lw={self.other_circle_lw}, '
                 f'other_circle_ls={self.other_circle_ls}, ')
 
-    def make_pizza(self, values, compare_values=None, bottom=0.0, figsize=(24, 16),
-                   ax=None, param_location=108, slice_colors=None, value_colors=None,
+    def make_pizza(self, values, alt_text_values=None, compare_values=None,
+                   alt_text_compare_values=None,
+                   bottom=0.0, figsize=(24, 16), ax=None, param_location=108,
+                   slice_colors=None, value_colors=None,
                    compare_colors=None, value_bck_colors=None, compare_value_colors=None,
                    compare_value_bck_colors=None, color_blank_space=None, blank_alpha=0.5,
                    kwargs_slices=None, kwargs_compare=None, kwargs_params=None, kwargs_values=None,
@@ -102,8 +114,14 @@ class PyPizza:
             ----------
             values : sequence of floats/int
                 Values for each parameter.
+            alt_text_values: sequence of floats/int, default None
+                Text to display in the text box for each slice.  If None is specified
+                the value is used.
             compare_values : sequence of floats/int, default None
                 Comparison Values for each parameter.
+            alt_text_compare_values: sequence of floats/int, default None
+                Text to display in the text box for each comparison slice.  If None is specified
+                the compare_value is used.
             bottom : float, default 0.0
                 Start value for the bar.
             figsize : tuple of floats, default (24, 16)
@@ -264,10 +282,24 @@ class PyPizza:
         self.__setup_pizza(ax, width)
 
         # add text
+        if alt_text_values is not None:
+            if len(alt_text_values) != len(values):
+                raise Exception("Length of alt_text_values and values are not equal!!!")
+            text_values = alt_text_values
+        else:
+            text_values = values
+
+        if alt_text_compare_values is not None:
+            if len(alt_text_compare_values) != len(compare_values):
+                raise_text = "Length of alt_text_compare_values and compare_values are not equal!!!"
+                raise Exception(raise_text)
+            text_compare_values = alt_text_compare_values
+        else:
+            text_compare_values = compare_values
         self.__add_texts(
-            ax, values, param_location,
+            ax, text_values, param_location,
             value_colors=value_colors, value_bck_colors=value_bck_colors,
-            compare_values=compare_values, compare_value_colors=compare_value_colors,
+            compare_values=text_compare_values, compare_value_colors=compare_value_colors,
             temp_values=temp_values, temp_compare_values=temp_compare_values,
             compare_value_bck_colors=compare_value_bck_colors,
             kwargs_params=kwargs_params, kwargs_values=kwargs_values,
@@ -279,7 +311,7 @@ class PyPizza:
         return None
 
     def __setup_pizza(self, ax, width):
-        """To setup the pizza plot.
+        """To set up the pizza plot.
 
             Parameters
             ----------
@@ -316,6 +348,7 @@ class PyPizza:
         gridlines = ax.yaxis.get_gridlines()
         gridlines[index].set_color(self.last_circle_color)
         gridlines[index].set_linewidth(self.last_circle_lw)
+
         gridlines[index].set_linestyle(self.last_circle_ls)
 
         # for other circles excluding last circle
@@ -443,7 +476,7 @@ class PyPizza:
         range_max = np.maximum(self.min_range, self.max_range)
         values_clipped = np.minimum(np.maximum(values, range_min), range_max)
         proportion = np.abs(values_clipped - self.min_range) / label_range
-        vertices = (proportion * 100)
+        vertices = proportion * 100
 
         return vertices
 
