@@ -29,13 +29,13 @@ class Radar:
         Minimum and maximum range for each parameter (inner and outer edge of the Radar).
     lower_is_better : sequence of str, default None
         Any params where it is better to have a lower statistic should be in this list.
-        If any of the strings match the params the the statistic will be flipped.
+        If any of the strings match the params the statistic will be flipped.
         In soccer, this is useful for parameters like miss-controls
         where fewer miss-controls is better than more.
         The default (None), which does not flip any statistic.
     round_int : sequence of bool, default None
         Whether to round the respective range values to integers (if True) or floats (if False).
-        The default (None) sets all range values to floats.
+        The default (None) sets all range values to float.
     num_rings : int, default 4
         The number of concentric circles. This excludes the center circle so the
         total number is num_rings + 1.
@@ -56,7 +56,7 @@ class Radar:
             self.greater_is_better = np.array([True] * self.params.size)
         else:
             lower_is_better = [param.lower().strip() for param in lower_is_better]
-            self.greater_is_better = np.asarray([param.lower().strip() not in lower_is_better 
+            self.greater_is_better = np.asarray([param.lower().strip() not in lower_is_better
                                                  for param in params])
         if round_int is None:
             self.round_int = np.array([False] * self.params.size)
@@ -79,9 +79,9 @@ class Radar:
             msg = 'The size of params and max_range must match'
             raise ValueError(msg)
         if (self.max_range < self.min_range).sum() > 0:
-            msg = ('The maximum range should be greater than the minimum range '
-                   'to flip the statistic(s) set the argument '
-                   f'greater_is_better={max_range >= min_range}')
+            msg = ('The maximum range should be greater than the minimum range. '
+                   'If you want to flip the statistic(s) add the parameter '
+                   'to the argument lower_is_better. For example, lower_is_better=["Miscontrols"]')
             raise TypeError(msg)
         if self.params.size != self.round_int.size:
             msg = 'The size of params and round_int must match'
@@ -92,7 +92,7 @@ class Radar:
         if self.params.size < 3:
             msg = 'You are not making a pretty chart. Increase the number of params to 3 or more.'
             raise ValueError(msg)
-        
+
         # flip the min_range and max_range if the argument greater_is_better is False
         # for a parameter
         # typically in soccer this would be for parameters like miscontrols where
@@ -142,7 +142,7 @@ class Radar:
         set_visible(ax)
 
     def setup_axis(self, facecolor='#FFFFFF', figsize=(12, 12), ax=None, **kwargs):
-        """ Setup an axis for plotting radar charts. If an ax is specified the settings are applied
+        """ Set up an axis for plotting radar charts. If an ax is specified the settings are applied
          to an existing axis. This method equalises the aspect ratio,
          and sets the facecolor and limits.
 
@@ -165,14 +165,14 @@ class Radar:
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
 
         >>> from mplsoccer import Radar
         >>> import matplotlib.pyplot as plt
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = plt.subplots(figsize=(12, 12))
         >>> radar.setup_axis(ax=ax)
         """
@@ -202,8 +202,8 @@ max_range=[10, 10, 10])
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         """
@@ -242,7 +242,7 @@ max_range=[10, 10, 10])
         radar = Polygon(vertices, **kwargs)
         radar = ax.add_patch(radar)
         return radar, vertices
-    
+
     def draw_radar_solid(self, values, ax=None, kwargs=None):
         """ Draw a single radar (polygon) without cliping to the rings.
 
@@ -264,13 +264,14 @@ max_range=[10, 10, 10])
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         >>> values = [5, 3, 10]
-        >>> radar_poly, vertices = radar.draw_radar_solid(values, ax=ax, \
-kwargs_radar={'facecolor': '#00f2c1', 'alpha': 0.6})
+        >>> radar_poly, vertices = radar.draw_radar_solid(values, ax=ax,
+        ...                                               kwargs={'facecolor': '#00f2c1',
+        ...                                                       'alpha': 0.6})
         """
         validate_ax(ax)
         if kwargs is None:
@@ -307,14 +308,16 @@ kwargs_radar={'facecolor': '#00f2c1', 'alpha': 0.6})
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         >>> values = [5, 3, 10]
-        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax, \
-kwargs_radar={'facecolor': '#00f2c1', 'alpha': 0.6}, \
-kwargs_rings={'facecolor': '#d80499', 'alpha': 0.6})
+        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax,
+        ...                                                kwargs_radar={'facecolor': '#00f2c1',
+        ...                                                              'alpha': 0.6},
+        ...                                                kwargs_rings={'facecolor': '#d80499',
+        ...                                                              'alpha': 0.6})
         """
         validate_ax(ax)
         if kwargs_radar is None:
@@ -362,15 +365,17 @@ kwargs_rings={'facecolor': '#d80499', 'alpha': 0.6})
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         >>> values = [5, 3, 10]
         >>> compare_values = [10, 4, 3]
-        >>> radar_output = radar.draw_radar_compare(values, compare_values, ax=ax, \
-kwargs_radar={'facecolor': '#00f2c1', 'alpha': 0.6}, \
-kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
+        >>> radar_output = radar.draw_radar_compare(values, compare_values, ax=ax,
+        ...                                         kwargs_radar={'facecolor': '#00f2c1',
+        ...                                                       'alpha': 0.6},
+        ...                                         kwargs_compare={'facecolor': '#d80499',
+        ...                                                         'alpha': 0.6})
         """
         validate_ax(ax)
         if kwargs_radar is None:
@@ -417,23 +422,23 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-                          max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         >>> values = [5, 3, 10]
-        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax, \
-                                                           kwargs_radar={'facecolor': '#00f2c1', \
-                                                                         'alpha': 0.6}, \
-                                                           kwargs_rings={'facecolor': '#d80499', \
-                                                                         'alpha': 0.6})
+        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax,
+        ...                                                kwargs_radar={'facecolor': '#00f2c1',
+        ...                                                              'alpha': 0.6},
+        ...                                                kwargs_rings={'facecolor': '#d80499',
+        ...                                                              'alpha': 0.6})
         >>> range_labels = radar.draw_range_labels(ax=ax)
         """
         validate_ax(ax)
         # create the label values - linearly interpolate between the low and high for each circle
         label_values = np.linspace(self.min_range.reshape(-1, 1), self.max_range.reshape(-1, 1),
                                    num=self.num_rings + 1, axis=1).ravel()
-        # remove the first entry so we do not label the inner circle
+        # remove the first entry so that we do not label the inner circle
         mask = np.ones_like(label_values, dtype=bool)
         mask[0::self.num_rings + 1] = 0
         label_values = label_values[mask]
@@ -450,7 +455,7 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         label_radius = np.linspace(self.ring_width,
                                    self.ring_width * self.num_rings,
                                    self.num_rings)
-        label_radius = (self.center_circle_radius + offset + label_radius)
+        label_radius = self.center_circle_radius + offset + label_radius
         label_xs = np.tile(label_radius, self.num_labels) * np.repeat(self.rotation_sin,
                                                                       label_radius.size)
         label_ys = np.tile(label_radius, self.num_labels) * np.repeat(self.rotation_cos,
@@ -484,16 +489,16 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-                          max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         >>> values = [5, 3, 10]
-        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax, \
-                                                           kwargs_radar={'facecolor': '#00f2c1', \
-                                                                         'alpha': 0.6}, \
-                                                           kwargs_rings={'facecolor': '#d80499', \
-                                                                         'alpha': 0.6})
+        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax,
+        ...                                                kwargs_radar={'facecolor': '#00f2c1',
+        ...                                                              'alpha': 0.6},
+        ...                                                kwargs_rings={'facecolor': '#d80499',
+        ...                                                              'alpha': 0.6})
         >>> range_labels = radar.draw_range_labels(ax=ax)
         >>> param_labels = radar.draw_param_labels(ax=ax)
         """
@@ -530,16 +535,16 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         Examples
         --------
         >>> from mplsoccer import Radar
-        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0], \
-                          max_range=[10, 10, 10])
+        >>> radar = Radar(params=['Agility', 'Speed', 'Strength'], min_range=[0, 0, 0],
+        ...               max_range=[10, 10, 10])
         >>> fig, ax = radar.setup_axis()
         >>> rings_inner = radar.draw_circles(ax=ax, facecolor='#ffb2b2', edgecolor='#fc5f5f')
         >>> values = [5, 3, 10]
-        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax, \
-                                                           kwargs_radar={'facecolor': '#00f2c1', \
-                                                                         'alpha': 0.6}, \
-                                                           kwargs_rings={'facecolor': '#d80499', \
-                                                                         'alpha': 0.6})
+        >>> radar_poly, rings, vertices = radar.draw_radar(values, ax=ax,
+        ...                                                kwargs_radar={'facecolor': '#00f2c1',
+        ...                                                              'alpha': 0.6},
+        ...                                                kwargs_rings={'facecolor': '#d80499',
+        ...                                                              'alpha': 0.6})
         >>> range_labels = radar.draw_range_labels(ax=ax)
         >>> param_labels = radar.draw_param_labels(ax=ax)
         >>> spokes = radar.spoke(ax=ax)
@@ -553,9 +558,7 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         spoke_y = np.repeat(spoke_y, 3)
         spoke_y[0::3] = 0
         spoke_y[2::3] = np.nan
-
-        lines = ax.plot(spoke_x, spoke_y, **kwargs)
-        return lines
+        return ax.plot(spoke_x, spoke_y, **kwargs)
 
     def _setup_cmap_circle(self):
         x, y = np.meshgrid(np.linspace(-self.lim, self.lim, 1000),
@@ -567,11 +570,10 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         self.circle_cmap_values = radius
 
     def _plot_cmap_circle(self, ax=None, cmap=None):
-        gradient = ax.imshow(self.circle_cmap_values, origin='lower',
-                             interpolation='bilinear',
-                             extent=[-self.lim, self.lim, -self.lim, self.lim],
-                             cmap=cmap)
-        return gradient
+        return ax.imshow(self.circle_cmap_values, origin='lower',
+                         interpolation='bilinear',
+                         extent=[-self.lim, self.lim, -self.lim, self.lim],
+                         cmap=cmap)
 
     def _rotated_kde_points(self, distribution_values, x_value, min_value,
                             max_value, rotation, scale=0.85):
@@ -667,12 +669,12 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         >>> lower, upper, mu, sigma = 0, 1, 0.35, 0.25
         >>> X = stats.truncnorm((lower - mu) / sigma, (upper - mu) / sigma, loc=mu, scale=sigma)
         >>> values = X.rvs((1000, 11))
-        >>> params = ['Expected goals', 'Total shots', \
-                      'Touches in attacking penalty area', 'Pass completion %', \
-                      'Crosses into the 18-yard box (excluding set pieces)', \
-                      'Expected goals assisted', 'Fouls drawn', 'Successful dribbles', \
-                      'Successful pressures', 'Non-penalty expected goals per shot', \
-                      'Miscontrols/ Dispossessed']
+        >>> params = ['Expected goals', 'Total shots',
+        ...           'Touches in attacking penalty area', 'Pass completion %',
+        ...           'Crosses into the 18-yard box (excluding set pieces)',
+        ...           'Expected goals assisted', 'Fouls drawn', 'Successful dribbles',
+        ...           'Successful pressures', 'Non-penalty expected goals per shot',
+        ...           'Miscontrols/ Dispossessed']
         >>> df = pd.DataFrame(values)
         >>> df.columns = params
         >>> df['player_name'] = np.arange(1000)
@@ -681,13 +683,13 @@ kwargs_compare={'facecolor': '#d80499', 'alpha': 0.6})
         >>> radar = Radar(params, low, high, num_rings=4)
         >>> player_values = df.loc[df.player_name == 23, params].values[0]
         >>> fig, ax = radar.setup_axis()
-        >>> turbine_output = radar.turbine(player_values, df[params].values, ax=ax, \
-                                           kwargs_inner={'edgecolor': 'black'},
-                                           kwargs_inner_gradient={'cmap': 'Blues'},
-                                           kwargs_outer={'facecolor': '#b2b2b2',
-                                           'edgecolor': 'black'})
-        >>> rings_inner = radar.draw_circles(ax=ax, facecolor='None', \
-                                             edgecolor='black', linestyle='--')
+        >>> turbine_output = radar.turbine(player_values, df[params].values, ax=ax,
+        ...                                kwargs_inner={'edgecolor': 'black'},
+        ...                                kwargs_inner_gradient={'cmap': 'Blues'},
+        ...                                kwargs_outer={'facecolor': '#b2b2b2',
+        ...                                'edgecolor': 'black'})
+        >>> rings_inner = radar.draw_circles(ax=ax, facecolor='None',
+        ...                                  edgecolor='black', linestyle='--')
         >>> range_labels = radar.draw_range_labels(ax=ax, fontsize=15, zorder=2)
         >>> param_labels = radar.draw_param_labels(ax=ax, fontsize=15, zorder=2)
         """
