@@ -1,8 +1,10 @@
+"""`mplsoccer.statsbomb` is a python module for loading StatsBomb open, local and API data."""
+
+import json
 import os
 
 import pandas as pd
 import requests
-import json
 
 __all__ = ['Sbopen', 'Sbapi', 'Sblocal']
 
@@ -33,7 +35,7 @@ class Sbopen:
 
         Returns
         -------
-        json-encoded content of a requests response
+        json-encoded content of a request's response
             For the StatsBomb data this is typically a list of dictionaries.
         """
         resp = requests.get(url=url)
@@ -123,9 +125,7 @@ class Sbopen:
         """
         url = f'{self.url}competitions.json'
         data = self._get_data(url)
-        if self.dataframe:
-            return pd.DataFrame(data)
-        return data
+        return pd.DataFrame(data) if self.dataframe else data
 
     def frame(self, match_id):
         """ StatsBomb 360 open-data.
@@ -185,7 +185,7 @@ class Sbapi:
 
         Returns
         -------
-        json-encoded content of a requests response
+        json-encoded content of a request's response
             For the StatsBomb data this is typically a list of dictionaries.
         """
         resp = requests.get(url=url, auth=self.auth)
@@ -282,9 +282,7 @@ class Sbapi:
         """
         url = f'{self.url}{version}/competitions'
         data = self._get_data(url)
-        if self.dataframe:
-            return pd.DataFrame(data)
-        return data
+        return pd.DataFrame(data) if self.dataframe else data
 
     def frame(self, match_id, version=1):
         """ StatsBomb 360 data from the API.
@@ -353,8 +351,8 @@ class Sblocal:
 
         Examples
         --------
-        >>> from mplsoccer import Sbopen
-        >>> parser = Sbopen(dataframe=True)
+        >>> from mplsoccer import Sblocal
+        >>> parser = Sblocal(dataframe=True)
         >>> events, related, freeze, tactics = parser.event(path)
         """
         data = self._get_data(path)
@@ -375,8 +373,8 @@ class Sblocal:
 
         Examples
         --------
-        >>> from mplsoccer import Sbopen
-        >>> parser = Sbopen(dataframe=True)
+        >>> from mplsoccer import Sblocal
+        >>> parser = Sblocal(dataframe=True)
         >>> lineups = parser.lineup(path)
         """
         data = self._get_data(path)
@@ -397,8 +395,8 @@ class Sblocal:
 
         Examples
         --------
-        >>> from mplsoccer import Sbopen
-        >>> parser = Sbopen(dataframe=True)
+        >>> from mplsoccer import Sblocal
+        >>> parser = Sblocal(dataframe=True)
         >>> matches = parser.match(path)
         """
         data = self._get_data(path)
@@ -418,14 +416,12 @@ class Sblocal:
 
         Examples
         --------
-        >>> from mplsoccer import Sbopen
-        >>> parser = Sbopen(dataframe=True)
+        >>> from mplsoccer import Sblocal
+        >>> parser = Sblocal(dataframe=True)
         >>> competition = parser.competition(path)
         """
         data = self._get_data(path)
-        if self.dataframe:
-            return pd.DataFrame(data)
-        return data
+        return pd.DataFrame(data) if self.dataframe else data
 
     def frame(self, path):
         """ Read the 360 data from a local file.
@@ -442,8 +438,8 @@ class Sblocal:
 
         Examples
         --------
-        >>> from mplsoccer import Sbopen
-        >>> parser = Sbopen(dataframe=True)
+        >>> from mplsoccer import Sblocal
+        >>> parser = Sblocal(dataframe=True)
         >>> frames, visible = parser.frame(path)
         """
         data = self._get_data(path)
@@ -508,6 +504,12 @@ def _event_dataframe(data):
     df = pd.DataFrame(data)
     if df.empty:
         return None
+    # tactics_formation from float to string
+    mask = df['tactics_formation'].notnull()
+    tactics = df.loc[mask, 'tactics_formation'].astype(int).astype(str)
+    df['tactics_formation'] = df['tactics_formation'].astype(str)
+    df.loc[mask, 'tactics_formation'] = tactics
+    df.loc[~mask, 'tactics_formation'] = None
     df['timestamp'] = pd.to_datetime(df['timestamp']).dt.time
     df.sort_values(['period', 'timestamp', 'index'], inplace=True)
     df.reset_index(drop=True, inplace=True)
@@ -560,7 +562,10 @@ def _match_dataframe(data):
                  'home_team_managers_dob', 'away_team_managers_dob']
     for date in date_cols:
         if date in df.columns:
-            df[date] = pd.to_datetime(df[date])
+            if pd.__version__ < '2':
+                df[date] = pd.to_datetime(df[date])
+            else:
+                df[date] = pd.to_datetime(df[date], format='ISO8601')
     return df
 
 
@@ -586,11 +591,18 @@ def flatten_event(events, match_id, dataframe=True):
     related = []
     freeze = []
     tactics = []
+    cols_to_drop = ['pass_through_ball', 'pass_outswinging', 'pass_inswinging', 'clearance_head',
+                    'clearance_left_foot', 'clearance_right_foot', 'pass_straight',
+                    'clearance_other', 'goalkeeper_punched_out',
+                    'goalkeeper_shot_saved_off_target', 'shot_saved_off_target',
+                    'goalkeeper_shot_saved_to_post', 'shot_saved_to_post', 'goalkeeper_lost_out',
+                    'goalkeeper_lost_in_play', 'goalkeeper_success_out',
+                    'goalkeeper_success_in_play', 'goalkeeper_saved_to_post',
+                    'shot_kick_off', 'goalkeeper_penalty_saved_to_post']
+
     for row in events:
         row['match_id'] = match_id
         for key in list(row):
-
-            # unpack nested columns
             if isinstance(row[key], dict):
                 for nested_key in list(row[key]):
                     nested_value = row[key][nested_key]
@@ -614,54 +626,28 @@ def flatten_event(events, match_id, dataframe=True):
                     else:
                         row[f'{key}_{nested_key}'] = nested_value
                 del row[key]
-
-        # unpack the location column
         if 'location' in row:
             _flatten_location(row, row['location'])
             del row['location']
-
-        # replace random star in ball receipts in some rows
         row['type_name'] = row['type_name'].replace('Ball Receipt*', 'Ball Receipt')
-
         # pass through ball is deprecated now, but it was not always added to technique name
         if 'pass_through_ball' in row:
             row['technique_name'] = 'Through Ball'
-
-        # drop cols that are covered by other columns
-        # (e.g. pass technique covers through, ball, inswinging etc.)
-        cols_to_drop = ['pass_through_ball', 'pass_outswinging', 'pass_inswinging',
-                        'clearance_head', 'clearance_left_foot', 'clearance_right_foot',
-                        'pass_straight', 'clearance_other', 'goalkeeper_punched_out',
-                        'goalkeeper_shot_saved_off_target', 'shot_saved_off_target',
-                        'goalkeeper_shot_saved_to_post', 'shot_saved_to_post',
-                        'goalkeeper_lost_out', 'goalkeeper_lost_in_play',
-                        'goalkeeper_success_out', 'goalkeeper_success_in_play',
-                        'goalkeeper_saved_to_post', 'shot_kick_off',
-                        'goalkeeper_penalty_saved_to_post',
-                        ]
         for col in cols_to_drop:
             row.pop(col, None)
-
-        # remove related_events as storing as separate dictionary
         if 'related_events' in row:
-            for related_event in row['related_events']:
-                related.append({'match_id': match_id,
-                                'id': row['id'],
-                                'index': row['index'],
-                                'type_name': row['type_name'],
-                                'id_related': related_event})
-            del row['related_events']
+            related.extend({'match_id': match_id, 'id': row['id'], 'index': row['index'],
+                            'type_name': row['type_name'], 'id_related': related_event}
+                           for related_event in row['related_events'])
 
-    # flatten list of lists (e.g. player in lineup or freeze-frame into separate entry)
+            del row['related_events']
     tactics = _flatten_list_of_lists(tactics, key='event_tactics_id')
     freeze = _flatten_list_of_lists(freeze, key='event_freeze_id')
-
     if dataframe:
         events = _event_dataframe(events)
         related = _related_dataframe(related, events)
         freeze = pd.DataFrame(freeze)
         tactics = pd.DataFrame(tactics)
-
     return events, related, freeze, tactics
 
 
@@ -694,7 +680,7 @@ def flatten_lineup(data, match_id, dataframe=True):
                 player['country_id'] = player['country']['id']
                 player['country_name'] = player['country']['name']
                 del player['country']
-            if player['player_nickname'] is None:
+            if 'player_nickname' in player and player['player_nickname'] is None:
                 player['player_nickname'] = player['player_name']
             player.pop('positions', None)  # if flattened would be multiple lines
             player.pop('cards', None)  # if flattened would be multiple lines
@@ -733,13 +719,12 @@ def flatten_match(match, dataframe=True):
                         for k in list(nested_value):
                             if k == 'nickname' and not nested_value[k]:
                                 row[f'{key}_{nested_key}_{k}'] = nested_value['name']
+                            elif isinstance(nested_value[k], dict):
+                                for sub_k in nested_value[k]:
+                                    nested_sub_value = nested_value[k][sub_k]
+                                    row[f'{key}_{nested_key}_{k}_{sub_k}'] = nested_sub_value
                             else:
-                                if isinstance(nested_value[k], dict):
-                                    for sub_k in nested_value[k]:
-                                        nested_sub_value = nested_value[k][sub_k]
-                                        row[f'{key}_{nested_key}_{k}_{sub_k}'] = nested_sub_value
-                                else:
-                                    row[f'{key}_{nested_key}_{k}'] = nested_value[k]
+                                row[f'{key}_{nested_key}_{k}'] = nested_value[k]
                     elif key in ['competition_stage', 'stadium', 'referee', 'metadata']:
                         row[f'{key}_{nested_key}'] = nested_value
                     else:
@@ -772,7 +757,7 @@ def flatten_360(data, match_id, dataframe=True):
     frames = []
     visible = []
     for row in data:
-        for idx, frame in enumerate(row['freeze_frame']):
+        for frame in row['freeze_frame']:
             frame['match_id'] = match_id
             frame['id'] = row['event_uuid']
             _flatten_location(frame, frame['location'])
